@@ -27,6 +27,7 @@ using namespace Kontact;
 #include <KontactInterface/Core>
 #include <KontactInterface/Plugin>
 
+#include <QApplication>
 #include <QAction>
 #include <QIcon>
 #include <KLocalizedString>
@@ -405,6 +406,9 @@ QSize Navigator::sizeHint() const
         maxWidth = qMax(maxWidth, sizeHintForIndex(index).width());
     }
 
+    // Take vertical scrollbar into account
+    maxWidth += qApp->style()->pixelMetric(QStyle::PM_ScrollBarExtent);
+
     int viewHeight = QListView::sizeHint().height();
 
     QSize size(maxWidth + rect().width() - contentsRect().width(), viewHeight);
