@@ -54,7 +54,7 @@ class KontactApp : public KontactInterface::PimUniqueApplication
 public:
     KontactApp(int &argc, char **argv[])
         : KontactInterface::PimUniqueApplication(argc, argv)
-        , mMainWindow(Q_NULLPTR)
+        , mMainWindow(nullptr)
         , mSessionRestored(false)
     {
     }
@@ -174,7 +174,7 @@ int main(int argc, char **argv)
                      QLatin1String(version),
                      i18n("KDE personal information manager"),
                      KAboutLicense::GPL,
-                     i18n("Copyright © 2001–2016 Kontact authors"),
+                     i18n("Copyright © 2001–2017 Kontact authors"),
                      QString(),
                      QStringLiteral("https://userbase.kde.org/Kontact"));
 
